#!/usr/bin/python3
# -*- coding: UTF-8 -*-
#
# GNU General Public License v3.0
#
# Permissions of this strong copyleft license are conditioned on making available
# complete source code of licensed works and modifications, which include larger works
# using a licensed work, under the same license. Copyright and license notices must be
# preserved. Contributors provide an express grant of patent rights.
#
# For more information on this, and how to apply and follow theGNU GPL, see:
# http://www.gnu.org/licenses
#
# Iván Rincón 2018

# import generator.transliterations as transliteration
#
# from base.countries_ops import *
# from .td1 import TD1CodeGenerator
# from .td2 import TD2CodeGenerator
# from .td3 import TD3CodeGenerator
#
# __all__ = ["TD1CodeGenerator", "TD2CodeGenerator", "TD3CodeGenerator", "transliteration",
#            "code_list", "countries_list", "countries_code_list", "code_country_list", "is_country",
#            "is_code", "get_code", "get_country", "find_country"]
