# -*- coding: UTF-8 -*-

# GNU General Public License v3.0
#
# Permissions of this strong copyleft license are conditioned on making available
# complete source code of licensed works and modifications, which include larger works
# using a licensed work, under the same license. Copyright and license notices must be
# preserved. Contributors provide an express grant of patent rights.
#
# For more information on this, and how to apply and follow theGNU GPL, see:
# http://www.gnu.org/licenses
#
# (ɔ) Iván Rincón 2018


# Modern greek (Experimental)

transliteration = {
    u"\u0027": "",
    u"\u0386": "A", u"\u03AC": "a",    # Ά, ά
    u"\u0391": "A", u"\u03B1": "a",    # Α, α
    u"\u0392": "B", u"\u03B2": "b",    # Β, β
    u"\u0393": "G", u"\u03B3": "g",    # Γ, γ
    u"\u0394": "D", u"\u03B4": "d",    # Δ, δ
    u"\u0395": "E", u"\u03B5": "e",    # Ε, ε
    u"\u0396": "Z", u"\u03B6": "z",    # Ζ, ζ
    u"\u0397": "I", u"\u03B7": "i",    # Η, η
    u"\u0398": "TH", u"\u03B8": "th",  # Θ, θ
    u"\u0399": "I", u"\u03B9": "i",    # Ι, ι
    u"\u039A": "K", u"\u03BA": "k",    # Κ, κ
    u"\u039B": "L", u"\u03BB": "l",    # Λ, λ
    u"\u039C": "M", u"\u03BC": "m",    # Μ, μ
    u"\u039D": "N", u"\u03BD": "n",    # Ν, ν
    u"\u039E": "X", u"\u03BE": "x",    # Ξ, ξ
    u"\u039F": "O", u"\u03BF": "o",    # Ο, ο
    u"\u03A0": "P", u"\u03C0": "p",    # Π, π
    u"\u03A1": "P", u"\u03C1": "p",    # Ρ, ρ
    u"\u03A3": "S", u"\u03C3": "s",    # Σ, σ
    u"\u03C2": "s",                    # ς
    u"\u03A4": "T", u"\u03C4": "t",    # Τ, τ
    u"\u03A5": "Y", u"\u03C5": "y",    # Υ, υ
    u"\u03A7": "CH", u"\u03C7": "ch",  # Χ, χ
    u"\u03A8": "PS", u"\u03C8": "ps",  # Ψ, ψ
    u"\u03A9": "O", u"\u03C9": "o",    # Ω, ω
    u"\u0388": "E", u"\u03AD": "e",    # Έ, έ
    u"\u0389": "I", u"\u03AE": "i",    # Ή, ή
    u"\u038A": "I", u"\u03AF": "i",    # Ί, ί
    u"\u038C": "O", u"\u03CC": "o",    # Ό, ό
    u"\u038E": "Y", u"\u03CD": "y",    # Ύ, ύ
    u"\u038F": "O", u"\u03CE": "o",    # Ώ, ώ
    u"\u03AA": "I", u"\u03CA": "i",    # Ϊ, ϊ
    u"\u03AB": "Y", u"\u03CB": "y",    # Ϋ, ϋ
}

# https://en.wikipedia.org/wiki/Romanization_of_Greek
