# -*- coding: utf-8 -*-
#
# GNU General Public License v3.0
#
# Permissions of this strong copyleft license are conditioned on making available
# complete source code of licensed works and modifications, which include larger works
# using a licensed work, under the same license. Copyright and license notices must be
# preserved. Contributors provide an express grant of patent rights.
#
# For more information on this, and how to apply and follow theGNU GPL, see:
# http://www.gnu.org/licenses
#
# (ɔ) Iván Rincón 2018

# TODO: Shorten
titles = [
    "MR",
    "SIR",
    "JR",
    "MRS",
    "MISS",
    "MS",
    "MADAM",
    "DAME",
    "DR",
    "LADY",
    "LORD",
    "MX",
    "ESQ",
    "HE",
    "HON",
    "PROF",
    "MEP",
    "MP",
    "BT",
    "HON",
    "QC",
    "KC",
    "HH",
    "HAH",
    "HE",
    "HMEH",
    "REVD",
    "REV",
    "FR",
    "PR",
    "BR",
    "IMAN",
    "MUFTI",
    "HAFIZ",
    "HAFIZAH",
    "QARI",
    "MAWLANA",
    "HAJI",
    "SAYYID",
    "SAYYIDAH",
    "SHARIF",
    "SRI",
    "SREE",
    "SHRI",
    "SHREE",
    "SIRI",
    "SERI",
    "SMT",
    "KUM",
    "HER",
    "FRAU",
    "SIE",
    "EXCMO",
    "ILMO"
]
